@@ -38,11 +38,9 @@ class Logger(object):
     def __init__(self):
         self.terminal = sys.stdout
         filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
-        self.log = open(filename, "a")
+        self.log = open(f"./{filename}", "a")
 
     def write(self, message):
-        timestamp = datetime.now().strftime("%d-%b-%Y (%H:%M:%S.%f)")
-        message = timestamp + message
         self.terminal.write(message)
         self.log.write(message)
 
@@ -65,22 +63,6 @@ def CommandWithConfigFile(config_file_param_name):
     return CustomCommandClass
 
 
-class Logger(object):
-    def flush(self):
-        pass
-
-    def __init__(self):
-        self.terminal = sys.stdout
-        filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
-        self.log = open(filename, "a")
-
-    def write(self, message):
-        # timestamp = datetime.now().strftime("%d-%b-%Y (%H:%M:%S.%f)")
-        # message = timestamp + message
-        self.terminal.write(message)
-        self.log.write(message)
-
-
 @click.command(cls=CommandWithConfigFile("config_file"))
 @click.option("--config-file", type=click.Path(), is_eager=True)
 @click.option(
@@ -134,6 +116,9 @@ def main(
     insecure,
 ):
     """Moves your on-prem DS deployment to the cloud!"""
+    sys.stdout = Logger()
+    sys.stderr = sys.stdout
+
     OLD_API_KEY = original_api_key
     OLD_HOST = original_url
     NEW_API_KEY = cloud_one_api_key
@@ -238,6 +223,7 @@ def main(
     )
 
     policy_dict = AddPolicy(allofpolicy, NEW_API_KEY)
+    computer_group_dict = {}
     computer_group_dict = computer_group_listmaker(
         OLD_HOST, OLD_API_KEY, NEW_HOST, NEW_API_KEY
     )
@@ -251,6 +237,4 @@ def main(
 
 
 if __name__ == "__main__":
-    sys.stdout = Logger()
-    sys.stderr = sys.stdout
     main()  # pylint: disable=no-value-for-parameter
